==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkOffScreenImage.h <==
// public class gnu.java.awt.peer.gtk.GtkOffScreenImage

// class file dependencies
// @dep_class 8209e894b3d4f9da gnu_java_awt_peer_gtk_GtkOffScreenImage
// @dep_class a583b2049538a9e0 java_awt_Image
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Image

#include "java/awt/Image.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$_init$59ba155781bc91e7(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getHeight$65fd8f44593d1096(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getProperty$4bfca031d28f9460(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getSource$2a89dcb615ac4789(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getWidth$f3efa3deabf3bc2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getHeight$65fd8f44593d1096;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getProperty$4bfca031d28f9460;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getSource$2a89dcb615ac4789;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getWidth$f3efa3deabf3bc2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
	jint	(*getHeight$65fd8f44593d1096)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*getProperty$4bfca031d28f9460)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	struct _jc_object	*(*getSource$2a89dcb615ac4789)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *);
	jint	(*getWidth$f3efa3deabf3bc2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Image$vmethods	java_awt_Image;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods	gnu_java_awt_peer_gtk_GtkOffScreenImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs {
	struct _jc_object	*source;
	struct _jc_java_awt_Graphics$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs	gnu_java_awt_peer_gtk_GtkOffScreenImage;
    _jc_java_awt_Image$sub_refs	java_awt_Image;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs {
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Image$sub_nonrefs	java_awt_Image;
    _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkOffScreenImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkOffScreenImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkOffScreenImage.h <==
// public class gnu.java.awt.peer.gtk.GtkOffScreenImage

// class file dependencies
// @dep_class 8209e894b3d4f9da gnu_java_awt_peer_gtk_GtkOffScreenImage
// @dep_class a583b2049538a9e0 java_awt_Image
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Image

#include "java/awt/Image.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$_init$59ba155781bc91e7(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getHeight$65fd8f44593d1096(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getProperty$4bfca031d28f9460(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getSource$2a89dcb615ac4789(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method$getWidth$f3efa3deabf3bc2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getHeight$65fd8f44593d1096;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getProperty$4bfca031d28f9460;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getSource$2a89dcb615ac4789;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$method_info$getWidth$f3efa3deabf3bc2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
	jint	(*getHeight$65fd8f44593d1096)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getProperty$4bfca031d28f9460)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSource$2a89dcb615ac4789)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *) _JC_JCNI_ATTR;
	jint	(*getWidth$f3efa3deabf3bc2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Image$vmethods	java_awt_Image;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vmethods	gnu_java_awt_peer_gtk_GtkOffScreenImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs {
	struct _jc_object	*source;
	struct _jc_java_awt_Graphics$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_refs	gnu_java_awt_peer_gtk_GtkOffScreenImage;
    _jc_java_awt_Image$sub_refs	java_awt_Image;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs {
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Image$sub_nonrefs	java_awt_Image;
    _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkOffScreenImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$vtype _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkOffScreenImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkOffScreenImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkOffScreenImage_H_ */
